# Project name here
> Summary description here.


This file will become your README and also the index of your documentation.

## Install

`pip install your_project_name`

## How to use

Since currently the functions are still being added and there are not many of them, the most convenient way is to simply `from Yikai_helper_funcs.core import * `.  This would give you all of the functions defined within the package. The names are carefully chosen thus they should not collide with your namespace.
